<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ota="http://www.opentravel.org/OTA">

	<xsl:key name="kOrdName" match="ota:SummaryResponse" use="@HotelName" />

	<xsl:template match="/">
		<xsl:choose>
			<xsl:when test="boolean(//ota:StandardError)">
				<div class="responseError">
					<span><h2>ERROR</h2></span><span><xsl:value-of select="//ota:StandardError"/></span>
				</div>
			</xsl:when>
			<xsl:when test="count(//ota:HotelReference)=0">
					<div class="legend">
						<h3>No hotels available</h3>
					</div>
			</xsl:when>
			<xsl:otherwise>
				<div>
					<h1>Hotel availability</h1>
					<div class="legend">
						<ul>
							<li><span class="icon"><img class="button" src="./img/book.gif"/></span> Selects the hotel to book it.</li>
							<li><span class="icon"><a class="map">[INFO]</a></span> Shows the hotel's location.</li>
							<li><span class="icon"><img class="button" src="./img/cancellation.gif"/></span> Displays de cancellation policy.</li>
						</ul>
					</div>
					<table>
						<caption>
							<span><xsl:value-of select="count(//ota:SummaryResponse[not(./ota:HotelReference/@HotelCode=preceding-sibling::ota:SummaryResponse//ota:HotelReference/@HotelCode)])"/> hotels selected</span>
						</caption>
						<thead>
							<tr>
								<th>Name</th>
								<th>Cat</th>
								<th>Room type</th>
								<th>Price</th>
								<th>Reg</th>
								<th>M. Rooms</th>
								<th>Availability</th>
								<th/>
								<th>Supplier</th>
								<th/>
							</tr>
						</thead>
						<tbody>
							<xsl:for-each select="//ota:SummaryResponse[not(./ota:HotelReference/@HotelCode=preceding-sibling::ota:SummaryResponse//ota:HotelReference/@HotelCode)]">
								<xsl:variable name="checkInDate"><xsl:value-of select="substring(.//StayDateRange/@StartDate,9,2)"/>-<xsl:value-of select="substring(.//StayDateRange/@StartDate,6,2)"/>-<xsl:value-of select="substring(.//StayDateRange/@StartDate,1,4)"/></xsl:variable>
								<xsl:variable name="checkOutDate"><xsl:value-of select="substring(.//StayDateRange/@EndDate,9,2)"/>-<xsl:value-of select="substring(.//StayDateRange/@EndDate,6,2)"/>-<xsl:value-of select="substring(.//StayDateRange/@EndDate,1,4)"/></xsl:variable>			
								<xsl:variable name="hotelId">
									<xsl:choose>
										<xsl:when test="ota:TPA_Extensions/ota:ConfirmationStatus/@Code!='C'">
											<xsl:value-of select="concat('request_', ./ota:HotelReference/@HotelCode )"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="concat('confirm_', ./ota:HotelReference/@HotelCode )"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<tr>
									<xsl:attribute name="id"><xsl:value-of select="concat('hotelSummary_', ./ota:HotelReference/@HotelCode)"/></xsl:attribute>
									<xsl:if test="position() mod 2=0">
										<xsl:attribute name="class">odd</xsl:attribute>
									</xsl:if>
									<td><xsl:value-of select="./@HotelName"/></td>
									<td><xsl:value-of select="./@HotelCat"/></td>
									<td><xsl:value-of select="./@ParsysRoomTypeName"/></td>
									<td align="right"><b><xsl:value-of select=".//ota:AdditionalDetail[./@Code = 'TotalPackagePrice']/@Amount"/></b></td>		
									<td><xsl:value-of select=".//ota:AdditionalDetailDate/@MealPlan"/></td>
									<td>
										<xsl:if test="./@MultipleRoom != '0'">
											<img class="button" src="./img/view.gif">
												<xsl:attribute name="onclick">getSelectedHotelInfo('<xsl:value-of select="concat('hotelSummary_', ./ota:HotelReference/@HotelCode)"/>');hotelAvRequestAllRooms('<xsl:value-of select="concat('hotelSummary_', ./ota:HotelReference/@HotelCode)"/>','<xsl:value-of select="$hotelId"/>', document.f1,'<xsl:value-of select="./@HotelName"/>')</xsl:attribute>	
											</img>
										</xsl:if>
									</td>
									<td align="center">
										<xsl:choose>
											<xsl:when test=".//ota:TPA_Extensions/ota:ConfirmationStatus/@Code = 'C'">
												<img src="./img/available.gif"/>
											</xsl:when>
											<xsl:when test=".//ota:TPA_Extensions/ota:ConfirmationStatus/@Code = 'P' and not(contains(.//ota:TPA_Extensions/ota:ConfirmationStatus/@Reason,'close'))">
												<img src="./img/onrequest.gif"/>
											</xsl:when>
											<xsl:otherwise>
												<img src="./img/closed_dates.gif"/>
											</xsl:otherwise>
										</xsl:choose>									
									</td>
									<td align="center">
										<img class="button" src="./img/book.gif">
											<xsl:attribute name="onclick">createRooms('<xsl:value-of select="concat('hotelSummary_', ./ota:HotelReference/@HotelCode)"/>', '<xsl:value-of select="./@RoomTypeCode"/>', '<xsl:value-of select="$hotelId"/>', document.f1,'<xsl:value-of select="./@HotelName"/>');</xsl:attribute>
										</img>
									</td>
									<td>
										<xsl:value-of select="./@HotelSupplier"/>
									</td>
									<td>
										<a class="map">
											<xsl:attribute name="onclick">showMap("<xsl:value-of select="./@HotelName"/>","<xsl:value-of select="./@HotelAddress" />");</xsl:attribute>
											[INFO]
										</a>									
									</td>
								</tr>
							</xsl:for-each>
						</tbody>
						<tfoot>
						</tfoot>
					</table>
				</div>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>