<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ota="http://www.opentravel.org/OTA">
	
	<xsl:decimal-format decimal-separator="," grouping-separator="."/>
	
	<xsl:template match="/">
		<xsl:choose>
			<xsl:when test="boolean(//StandardError)">
				<div class="responseError">
					<span><h4>ERROR</h4></span><span><xsl:value-of select="//StandardError"/></span>
				</div>
			</xsl:when>
			<xsl:otherwise>
				<div id="dossierInfo">
					<h1 class="center">Travel file info</h1>
					<div class="legend">
						<ul>
							<li>When the Add services buttons is enabled, it means there are possible available services those dates, press it to display them.</li>
						</ul>
					</div>
					<xsl:for-each select="//*[boolean(./@ReservationOriginatorCode)]">
						<xsl:sort select="number(concat(substring(.//StayDateRange/@StartDate,1,4),substring(.//StayDateRange/@StartDate,6,2),substring(.//StayDateRange/@StartDate,9,2)))"/>
						<div class="dossierItem">
						<p><br/></p>
						<xsl:apply-templates select=".">
							<xsl:with-param name="resPosition" select="position()"/>
						</xsl:apply-templates>
						</div>
						<xsl:if test="position()!=count(//*[boolean(./@ReservationOriginatorCode)])">
							<p><br/></p>
							<hr class="separator"/>
						</xsl:if>
					</xsl:for-each>
				</div>
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>

	<xsl:template name="namePrefix">
		<xsl:param name="current"/>
		<xsl:param name="roomCode"/>
		<xsl:param name="roomUseCode"/>
		<xsl:param name="roomIndex"/>
		<xsl:param name="pos"/>
		<xsl:param name="type"/>
		
     	<select>
     		<xsl:choose>
     			<xsl:when test="$type='H'">
		     		<xsl:attribute name="name">RoomType_<xsl:value-of select="$roomCode"/>_Use_<xsl:value-of select="$roomUseCode"/>_Num_<xsl:value-of select="$roomIndex"/>_Guest_<xsl:value-of select="$pos"/>_NamePrefix</xsl:attribute>
     			</xsl:when>
     			<xsl:otherwise>
		     		<xsl:attribute name="name">pax_num_<xsl:value-of select="$pos"/>_salu</xsl:attribute>
     			</xsl:otherwise>
     		</xsl:choose>
			<option value="Mr.">
				<xsl:if test="$current ='Mr.'"><xsl:attribute name="selected"/></xsl:if>
			 Mr.</option>
			<option value="Mrs.">
				<xsl:if test="$current ='Mrs.'"><xsl:attribute name="selected"/></xsl:if>
			 Mrs.</option>
			<option value="Miss.">
				<xsl:if test="$current ='Miss'"><xsl:attribute name="selected"/></xsl:if>
				 Miss.</option>
			<option value="Ms.">
				<xsl:if test="$current ='Ms.'"><xsl:attribute name="selected"/></xsl:if>
			 Ms.</option>
		</select>
	</xsl:template>
	
	<xsl:template name="childAge">
		<xsl:param name="current"/>
		<xsl:param name="roomCode"/>
		<xsl:param name="roomUseCode"/>
		<xsl:param name="roomIndex"/>
		<xsl:param name="pos"/>
		<xsl:param name="type"/>
     	<select>
     		<xsl:choose>
     			<xsl:when test="$type='H'">
		     		<xsl:attribute name="name">Room<xsl:value-of select="$roomIndex"/>ChildAge_<xsl:value-of select="$pos"/></xsl:attribute>
     			</xsl:when>
     			<xsl:otherwise>
		     		<xsl:attribute name="name">pax_num_<xsl:value-of select="$pos"/>_Age</xsl:attribute>
     			</xsl:otherwise>
     		</xsl:choose>
			<option value="A">
				<xsl:if test="$current ='A' or $current='Adult'"><xsl:attribute name="selected"/></xsl:if>
			 Adult</option>
			 <xsl:call-template name="createAgeOptions">
				<xsl:with-param name="current" select="$current"/>
				<xsl:with-param name="start" select="1"/>
				<xsl:with-param name="stop" select="18"/>
			 </xsl:call-template>
		</select>
	</xsl:template>

	<xsl:template name="createAgeOptions">
		<xsl:param name="current"/>
		<xsl:param name="start"/>
		<xsl:param name="stop"/>
		<xsl:if test="$start &lt;= $stop">
			<option>
				<xsl:attribute name="value"><xsl:value-of select="$start"/></xsl:attribute>
				<xsl:if test="$current = $start"><xsl:attribute name="selected"/></xsl:if>
			 <xsl:value-of select="$start"/></option>
			 <xsl:call-template name="createAgeOptions">
				<xsl:with-param name="current" select="$current"/>
				<xsl:with-param name="start" select="$start+1"/>
				<xsl:with-param name="stop" select="$stop"/>
			 </xsl:call-template>
		</xsl:if>
	</xsl:template>


	<xsl:template match="HotelReservation">
			<xsl:param name="resPosition"/>
			<xsl:variable name="checkInDate"><xsl:value-of select="substring(.//StayDateRange/@StartDate,9,2)"/>-<xsl:value-of select="substring(.//StayDateRange/@StartDate,6,2)"/>-<xsl:value-of select="substring(.//StayDateRange/@StartDate,1,4)"/></xsl:variable>
			<xsl:variable name="checkOutDate"><xsl:value-of select="substring(.//StayDateRange/@EndDate,9,2)"/>-<xsl:value-of select="substring(.//StayDateRange/@EndDate,6,2)"/>-<xsl:value-of select="substring(.//StayDateRange/@EndDate,1,4)"/></xsl:variable>
			<p>
			<label class="dossierTitleNumber">1</label><label class="dossierTitle"> - Hotel</label>
			<HR/>
			<label><b><xsl:value-of select=".//HotelReference/@HotelName"/></b></label><br/>
			<label><b>Dates</b></label><br/>
			<label>Arrival date: <xsl:value-of select="$checkInDate"/></label><br/>
			<label>Departure date: <xsl:value-of select="$checkOutDate"/></label><br/>
			<label class="separated25"><b>Country: </b><xsl:value-of select=".//HotelReference/@HotelCountry"/></label><label class="separated25"><b>City: </b><xsl:value-of select=".//HotelReference/@HotelCity"/></label><label class="separated25"><b>Cat: </b><xsl:value-of select=".//HotelReference/@HotelCat"/></label><br/>
			<label class="separated25"><b>Number of Rooms: </b><xsl:value-of select="sum(.//RoomStay/@NumberOfRooms)"/></label><label class="separated25"><b>Number of Adults: </b><xsl:value-of select="sum(.//GuestCount[@AgeQualifyingCode='A' or @AgeQualifyingCode='Adult' ]/@Count)"/></label><label class="separated25"><b>Number of Child: </b><xsl:value-of select="sum(.//GuestCount[@AgeQualifyingCode!='A' and @AgeQualifyingCode!='Adult']/@Count)"/></label><br/>
			</p>
			<p><br/></p>
			<p>
			<label class="dossierTitleNumber">2</label><label class="dossierTitle"> - Price</label>
			<HR/>
			<label class="separated25">
			<b><xsl:value-of select=".//RoomStay[1]/@NumberOfRooms"/><xsl:text> - </xsl:text><xsl:value-of select=".//RoomStay[1]/@ParsysRoomTypeName"/></b>
			</label>
			<label class="separated20"><xsl:value-of select="format-number(.//RoomStay[1]//RoomPrice * .//RoomStay[1]/@NumberOfRooms,'#0,00')"/><xsl:text> </xsl:text><xsl:value-of select=".//TotalPrice/@CurrencyCode"/></label>
			<label class="separated25">
			<b>Tot Price</b>
			</label>
			<label class="separated20">
			<xsl:value-of select="concat(format-number(.//TotalPrice/@IntPart,'#0'), ',' ,format-number(.//TotalPrice/@DecPart,'00'), ' ' , .//TotalPrice/@CurrencyCode)"/>
			</label>
			<br/>
			<label class="separated25">
			Adults
			</label>
			<label class="separated20">
			<xsl:value-of select=".//RoomStay[1]//GuestCount[@AgeQualifyingCode='A' or @AgeQualifyingCode='Adult' ]/@Count"/>
			</label>
			<br/>
			<label class="separated25">
			Children
			</label>
			<label class="separated20">
			<xsl:value-of select="sum(.//RoomStay[1]//GuestCount[@AgeQualifyingCode!='A' and @AgeQualifyingCode!='Adult' ]/@Count)"/>
			</label>
			<br/>
			<xsl:for-each select=".//RoomStay[position() &gt; 1]">
				<label class="separated25">
					<b><xsl:value-of select="./@NumberOfRooms"/><xsl:text> - </xsl:text><xsl:value-of select="./@ParsysRoomTypeName"/></b>
				</label>
				<label class="separated20">
					<xsl:value-of select="format-number(.//RoomPrice * ./@NumberOfRooms,'#0,00')"/><xsl:text> </xsl:text><xsl:value-of select="//TotalPrice/@CurrencyCode"/>		
				</label>
				<br/>
				<label class="separated25">
					Adults
				</label>
				<label class="separated20">
					<xsl:value-of select=".//GuestCount[@AgeQualifyingCode='A' or @AgeQualifyingCode='Adult' ]/@Count"/>
				</label>
				<br/>	
				<label class="separated25">
					Children
				</label>
				<label class="separated20">
				<xsl:value-of select="sum(.//GuestCount[@AgeQualifyingCode!='A' and @AgeQualifyingCode!='Adult' ]/@Count)"/>
				</label>
				<br/>
			</xsl:for-each>
			</p>
			<p><br/></p>
			<p>
			<label class="dossierTitleNumber">3</label><label class="dossierTitle"> - Reservation</label>
			<HR/>
			<label><b>Travel File: </b><xsl:value-of select=".//HotelReservationID[@ResIDType='Reservation']/@ResIDValue"/></label><br/>
			<label><b>Travel Agent Booking Ref: </b><xsl:value-of select=".//HotelReservationID[@ResIDType='YourRef']/@ResIDValue"/></label><br/>
			<p class="right">
				<xsl:choose>
					<xsl:when test=".//TPA_Extensions/ConfirmationStatus = 'N' and (.//TPA_Extensions/Type = 'R' or .//TPA_Extensions/Type = 'A' or .//TPA_Extensions/Type = 'M')">
						<img src="./img/confirmed.gif"/>
						</xsl:when>
					<xsl:when test="((.//TPA_Extensions/ConfirmationStatus = 'N' or .//TPA_Extensions/ConfirmationStatus = 'C') and .//TPA_Extensions/Type = 'C')">
						<label style="color: red"><b>CANCELLED</b></label>
					</xsl:when>
					<xsl:when test=".//TPA_Extensions/ConfirmationStatus = 'C' and (.//TPA_Extensions/Type = 'R' or .//TPA_Extensions/Type = 'A' or .//TPA_Extensions/Type = 'M')">
						<img src="./img/confirmed.gif"/>
					</xsl:when>
					<xsl:when test=".//TPA_Extensions/ConfirmationStatus = 'R' and (.//TPA_Extensions/Type = 'R' or .//TPA_Extensions/Type = 'A' or .//TPA_Extensions/Type = 'M')">
						<img src="./img/rejected.gif"/>
					</xsl:when>
					<xsl:when test=".//TPA_Extensions/ConfirmationStatus = 'P'">
						<label style="color: #A52A2A"><b>PENDING</b></label>
					</xsl:when>
				</xsl:choose>
			</p>
			<xsl:for-each select=".//RoomStay">
				<xsl:variable name="roomStayPos" select="position()"/>
				<label class="roomTitle">Room #<xsl:value-of select="position()"/> - <xsl:value-of select="./@ParsysRoomTypeName"/>/<xsl:value-of select="./@RoomUseName"/></label><br/>
				<span><b>Provider: </b><xsl:value-of select="./HotelReference/@HotelSupplier"/></span><br/>
				<span><b>File Provider: </b><xsl:value-of select=".//HotelReservationID[@ResIDType='SupplierLocator']/@ResIDValue"/></span><br/>
				<xsl:for-each select=".//ResGuestRPH">
					<xsl:variable name="indexRPH"><xsl:value-of select="."/></xsl:variable>
					<label class="separated20">
						<xsl:call-template name="namePrefix">
							<xsl:with-param name="current" select="//HotelReservation[$resPosition]//ResProfile[@ResProfileRPH = $indexRPH]//NamePrefix"/>
							<xsl:with-param name="roomCode" select="//HotelReservation[$resPosition]//RoomStay[$roomStayPos]/@RoomTypeCode"/>
							<xsl:with-param name="roomUseCode" select="//HotelReservation[$resPosition]//RoomStay[$roomStayPos]/@RoomUseCode"/>
							<xsl:with-param name="roomIndex" select="$roomStayPos"/>
							<xsl:with-param name="pos" select="position()"/>
							<xsl:with-param name="type">H</xsl:with-param>
							
						</xsl:call-template>
					</label>
					<label class="separated20">
						<b>Name: </b><input type="text">
						<xsl:attribute name="value">
							<xsl:value-of select="//HotelReservation[$resPosition]//ResProfile[@ResProfileRPH = $indexRPH]//GivenName"/>
						</xsl:attribute>
						<xsl:attribute name="name">
							PaxGivenName_<xsl:value-of select="$roomStayPos"/>_<xsl:value-of select="position()"/>
						</xsl:attribute>
					</input>
					</label>
					<label class="separated20">
						<b>Surname: </b><input type="text">
						<xsl:attribute name="value">
							<xsl:value-of select="//HotelReservation[$resPosition]//ResProfile[@ResProfileRPH = $indexRPH]//Surname"/>
						</xsl:attribute>
						<xsl:attribute name="name">
							PaxSurname_<xsl:value-of select="$roomStayPos"/>_<xsl:value-of select="position()"/>
						</xsl:attribute>
					</input>
					</label>
					<label class="separated20">
					<xsl:if test="//HotelReservation[$resPosition]//ResProfile[@ResProfileRPH = $indexRPH]//Age !='A' and //HotelReservation[$resPosition]//ResProfile[@ResProfileRPH = $indexRPH]//Age !='Adult' ">
						<xsl:if test="//HotelReservation[$resPosition]//ResProfile[@ResProfileRPH = $indexRPH]//Age &lt; 18">
							<td class="noborders"><b>Child Age: </b><xsl:call-template name="childAge">
								<xsl:with-param name="current" select="//HotelReservation[$resPosition]//ResProfile[@ResProfileRPH = $indexRPH]//Age"/>
								<xsl:with-param name="roomCode" select="//HotelReservation[$resPosition]//RoomStay[$roomStayPos]/@RoomTypeCode"/>
								<xsl:with-param name="roomUseCode" select="//HotelReservation[$resPosition]//RoomStay[$roomStayPos]/@RoomUseCode"/>
								<xsl:with-param name="roomIndex" select="$roomStayPos"/>
								<xsl:with-param name="pos" select="position()"/>
								<xsl:with-param name="type">H</xsl:with-param>
							</xsl:call-template>
							</td>
						</xsl:if>
					</xsl:if><xsl:text> </xsl:text>
					</label>
				<br/>
			</xsl:for-each>
			<p class="right">
			<label>
			<img class="button" src="./img/voucher.gif">
				<xsl:attribute name="onclick">printVoucher('<xsl:value-of select="//HotelReservation[$resPosition]//HotelReservationID[ @ResIDType = 'Reservation' ]/@ResIDValue"/>_<xsl:value-of select="//HotelReservation[$resPosition]//HotelReservationID[@ResIDType = 'Locator']/@ResIDValue"/>_<xsl:value-of select="./@RoomUseCode"/>_<xsl:value-of select="position() -1"/>_<xsl:value-of select="./@RoomTypeCode"/>')</xsl:attribute>
				<xsl:if test="not((//HotelReservation[$resPosition]//TPA_Extensions/ConfirmationStatus = 'N' and (//HotelReservation[$resPosition]//TPA_Extensions/Type = 'R' or //HotelReservation[$resPosition]//TPA_Extensions/Type = 'A' or //HotelReservation[$resPosition]//TPA_Extensions/Type = 'M')) or (//HotelReservation[$resPosition]//TPA_Extensions/ConfirmationStatus = 'C' and (//HotelReservation[$resPosition]//TPA_Extensions/Type = 'R' or //HotelReservation[$resPosition]//TPA_Extensions/Type = 'A' or //HotelReservation[$resPosition]//TPA_Extensions/Type = 'M')))">
					<xsl:attribute name="disabled"/>
				</xsl:if>
			</img>
			</label>
			</p>
		</xsl:for-each>
		<p class="center">
			<label>
			<xsl:if test="//HotelReservation[$resPosition]//HotelReference/@HotelSiteCode &lt; 2001 and (//HotelReservation[$resPosition]//TPA_Extensions/ConfirmationStatus = 'N' and (//HotelReservation[$resPosition]//TPA_Extensions/Type = 'R' or //HotelReservation[$resPosition]//TPA_Extensions/Type = 'A' or //HotelReservation[$resPosition]//TPA_Extensions/Type = 'M')) or (//HotelReservation[$resPosition]//TPA_Extensions/ConfirmationStatus = 'C' and (//HotelReservation[$resPosition]//TPA_Extensions/Type = 'R' or //HotelReservation[$resPosition]//TPA_Extensions/Type = 'A' or //HotelReservation[$resPosition]//TPA_Extensions/Type = 'M'))">
				<img class="button" src="./img/modify.gif" name="update">
					<xsl:attribute name="onclick">showToModHolteReservation('<xsl:value-of select="//HotelReservation[$resPosition]//HotelReservationID[@ResIDType = 'Locator']/@ResIDValue"/>');</xsl:attribute>
				</img>
			</xsl:if>
			</label>
			<label>
			<xsl:if test="(//HotelReservation[$resPosition]//TPA_Extensions/ConfirmationStatus = 'N' and (//HotelReservation[$resPosition]//TPA_Extensions/Type = 'R' or //HotelReservation[$resPosition]//TPA_Extensions/Type = 'A' or //HotelReservation[$resPosition]//TPA_Extensions/Type = 'M')) or (//HotelReservation[$resPosition]//TPA_Extensions/ConfirmationStatus = 'C' and (//HotelReservation[$resPosition]//TPA_Extensions/Type = 'R' or //HotelReservation[$resPosition]//TPA_Extensions/Type = 'A' or //HotelReservation[$resPosition]//TPA_Extensions/Type = 'M'))">
				<img class="button" src="./img/cancel.gif" name="cancel">
					<xsl:attribute name="onclick">cancelReservation('<xsl:value-of select="//HotelReservation[$resPosition]//HotelReservationID[@ResIDType = 'Locator']/@ResIDValue"/>','<xsl:value-of select="//HotelReservation[1]/HotelReservationIDs/HotelReservationID[ @ResIDType = 'Reservation' ]/@ResIDValue"/>')</xsl:attribute>
				</img>
			</xsl:if>
			</label>		
		</p>
		</p>
	</xsl:template>
	
	<xsl:template match="ServiceReservation">
			<xsl:param name="resPosition"/>
			<xsl:variable name="checkInDate"><xsl:value-of select="substring(.//StayDateRange/@StartDate,9,2)"/>-<xsl:value-of select="substring(.//StayDateRange/@StartDate,6,2)"/>-<xsl:value-of select="substring(.//StayDateRange/@StartDate,1,4)"/></xsl:variable>
			<p>
			<label class="dossierTitleNumber">1</label><label class="dossierTitle"><xsl:text> - </xsl:text>
			<xsl:choose>
				<xsl:when test="./@ServiceType = 2">
					Transfer In
				</xsl:when>
				<xsl:when test="./@ServiceType = -2">
					Transfer Out
				</xsl:when>
				<xsl:otherwise>
					Sightseeing
				</xsl:otherwise>
			</xsl:choose>
			</label>
			<HR/>
			<label><b><xsl:value-of select=".//ServiceReference/@ServiceName"/></b></label><br/>
			<label><b>Dates</b></label><br/>
			<label>Service date: <xsl:value-of select="$checkInDate"/></label><br/>
			<label class="separated25"><b>Country: </b><xsl:value-of select=".//ServiceReference/@Country"/></label><label class="separated25"><b>City: </b><xsl:value-of select=".//ServiceReference/@City"/></label><br/>
			<label class="separated25"><b>Number of Adults: </b><xsl:value-of select="count(.//Age[.='A' or .='Adult' ])"/></label><label class="separated25"><b>Number of Child: </b><xsl:value-of select="count(.//Age[.!='A' and .!='Adult' ])"/></label><br/>
			</p>
			<p><br/></p>
			<p>
			<label class="dossierTitleNumber">2</label><label class="dossierTitle"> - Price</label>
			<HR/>
			<label class="separated35">
			<b><xsl:value-of select=".//ServiceReference/@ServiceName"/></b>
			</label>
			<label class="separated20"><xsl:value-of select="concat(format-number(.//TPA_Extensions/TotalPrice/@IntPart,'0'),',',format-number(.//TPA_Extensions/TotalPrice/@DecPart,'00'))"/><xsl:text> </xsl:text><xsl:value-of select=".//TPA_Extensions/TotalPrice/@CurrencyCode"/></label>
			</p>
			<p><br/></p>
			<p>
			<label class="dossierTitleNumber">3</label><label class="dossierTitle"> - Reservation</label>
			<HR/>
			<label><b>Travel File: </b><xsl:value-of select=".//ServReservationID[@ResIDType='Reservation']/@ResIDValue"/></label><br/>
			<label><b>Travel Agent Booking Ref: </b><xsl:value-of select=".//ServReservationID[@ResIDType='YourRef']/@ResIDValue"/></label><br/>
			<p class="right">
				<xsl:choose>
					<xsl:when test=".//TPA_Extensions/ConfirmationStatus = 'N' and (.//TPA_Extensions/Type = 'R' or .//TPA_Extensions/Type = 'A' or .//TPA_Extensions/Type = 'M')">
						<img src="./img/confirmed.gif"/>
						</xsl:when>
					<xsl:when test="((.//TPA_Extensions/ConfirmationStatus = 'N' or .//TPA_Extensions/ConfirmationStatus = 'C') and .//TPA_Extensions/Type = 'C')">
						<img src="./img/cancel.gif"/>
					</xsl:when>
					<xsl:when test=".//TPA_Extensions/ConfirmationStatus = 'C' and (.//TPA_Extensions/Type = 'R' or .//TPA_Extensions/Type = 'A' or .//TPA_Extensions/Type = 'M')">
						<img src="./img/confirmed.gif"/>
					</xsl:when>
					<xsl:when test=".//TPA_Extensions/ConfirmationStatus = 'R' and (.//TPA_Extensions/Type = 'R' or .//TPA_Extensions/Type = 'A' or .//TPA_Extensions/Type = 'M')">
						<img src="./img/rejected.gif"/>
					</xsl:when>
					<xsl:when test=".//TPA_Extensions/ConfirmationStatus = 'P'">
						<label style="color: #A52A2A"><b>Pending</b></label>
					</xsl:when>
				</xsl:choose>
			</p>
			<p>
				<label class="roomTitle"><xsl:value-of select=".//ServiceReference/@ServiceName"/></label><br/>
				<span><b>Provider: </b><xsl:value-of select="./ServiceReference/@ServiceSupplier"/></span><br/>
				<span><b>File Provider: </b><xsl:value-of select=".//ServReservationID[@ResIDType='SupplierLocator']/@ResIDValue"/></span><br/>				
				<xsl:for-each select=".//ResGuestRPH">
					<xsl:variable name="indexRPH"><xsl:value-of select="."/></xsl:variable>
					<label class="separated20">
						<xsl:call-template name="namePrefix">
							<xsl:with-param name="current" select="//ServiceReservation[position() = $resPosition]//ResProfile[@ResProfileRPH = $indexRPH]//NamePrefix"/>
							<xsl:with-param name="pos" select="position()"/>
							<xsl:with-param name="type">S</xsl:with-param>
						</xsl:call-template>
					</label>
					<label class="separated20">
						<b>Name: </b><input type="text">
						<xsl:attribute name="value">
							<xsl:value-of select="//ServiceReservation[position() = $resPosition]//ResProfile[@ResProfileRPH = $indexRPH]//GivenName"/>
						</xsl:attribute>
						<xsl:attribute name="name">
							pax_num_<xsl:value-of select="position()"/>_name
						</xsl:attribute>
					</input>
					</label>
					<label class="separated20">
						<b>Surname: </b><input type="text">
						<xsl:attribute name="value">
							<xsl:value-of select="//ServiceReservation[position() = $resPosition]//ResProfile[@ResProfileRPH = $indexRPH]//Surname"/>
						</xsl:attribute>
						<xsl:attribute name="name">
							pax_num_<xsl:value-of select="position()"/>_surname
						</xsl:attribute>
					</input>
					</label>
					<label class="separated20">
					<xsl:if test="//ServiceReservation[position() = $resPosition]//ResProfile[@ResProfileRPH = $indexRPH]//Age !='A' and //ServiceReservation[position() = $resPosition]//ResProfile[@ResProfileRPH = $indexRPH]//Age !='Adult' ">
						<xsl:if test="//ServiceReservation[position() = $resPosition]//ResProfile[@ResProfileRPH = $indexRPH]//Age &lt; 18">
							<td class="noborders"><b>Child Age: </b><xsl:call-template name="childAge">
								<xsl:with-param name="current" select="//ServiceReservation[position() = $resPosition]//ResProfile[@ResProfileRPH = $indexRPH]//Age"/>
								<xsl:with-param name="pos" select="position()"/>
								<xsl:with-param name="type">S</xsl:with-param>
							</xsl:call-template>
							</td>
						</xsl:if>
					</xsl:if><xsl:text> </xsl:text>
					</label>
					<br/>
				</xsl:for-each>				
			</p>
			<p>
			<label class="separated20"></label><label class="separated10"><b>
			<xsl:choose>
				<xsl:when test="./@ServiceType = 2">
					Transfer to: 
				</xsl:when>
				<xsl:when test="./@ServiceType = -2">
					Transfer from: 
				</xsl:when>
				<xsl:otherwise>
					Hotel: 
				</xsl:otherwise>
			</xsl:choose>
			</b></label><label class="separated20"><input type="text">
						<xsl:attribute name="value">
							<xsl:value-of select=".//HotelName"/>
						</xsl:attribute>
						<xsl:attribute name="name">
							transfer_<xsl:value-of select="position()"/>_hotel
						</xsl:attribute>
					</input>
			</label>
			</p>
			<xsl:if test="./@ServiceType = -2 or ./@ServiceType = 2">
				<p>
				<label class="separated20"></label><label class="separated10"><b>Flight:</b></label><label class="separated20"><input type="text">
							<xsl:attribute name="value">
								<xsl:value-of select=".//TransportNumber"/>
							</xsl:attribute>
							<xsl:attribute name="name">
								transfer_<xsl:value-of select="position()"/>_hotel
							</xsl:attribute>
						</input>
				</label>
				<label class="separated10"><b>
				<xsl:choose>
					<xsl:when test="./@ServiceType = 2">
						From: 
					</xsl:when>
					<xsl:when test="./@ServiceType = -2">
						To: 
					</xsl:when>
				</xsl:choose>
				</b></label><label class="separated20"><input type="text">
							<xsl:attribute name="value">
								<xsl:value-of select=".//CityName"/>
							</xsl:attribute>
							<xsl:attribute name="name">
								transfer_<xsl:value-of select="position()"/>_city
							</xsl:attribute>
						</input>
				</label>
				</p>
			</xsl:if>
			<p><br/></p>
		</p>
	</xsl:template>

</xsl:stylesheet>
